.. :changelog:

History
-------

0.4.1 (2014-09-10)
++++++++++++++++++
* Fixed non unicode extracted variables

0.4.0 (2014-03-11)
++++++++++++++++++
* Added support for xml and json files

0.3.3 (2014-03-06)
++++++++++++++++++
* Added -e / --env option to ``ejpiaj-cli`` to pass initial variables
* Added -q / --quiet option to ``ejpiaj-cli`` to quiet output

0.3.2 (2014-02-17)
++++++++++++++++++
* Added -s option to ``ejpiaj-cli`` to display extracted variables

0.3.1 (2014-02-17)
++++++++++++++++++
* Fixed loading custom module from current directory

0.3.0 (2014-02-16)
++++++++++++++++++
* Added support to load own module with custom assertions and variable extractors
  using ``ejpiaj-cli`` tool

0.2.3 (2014-02-10)
++++++++++++++++++
* Fixed tests order (alphabetical)

0.2.2 (2014-02-10)
++++++++++++++++++
* Fixed variable substiution for multi varaibles
* Added variable substitution in 'url'

0.2.1 (2014-02-07)
++++++++++++++++++

* Fixed variables substitution if variable is None

0.2.0 (2014-02-07)
++++++++++++++++++

* Added support for form_params and headers

0.1.0 (2014-02-01)
++++++++++++++++++

* First release on PyPI.
